@@ -17,7 +17,12 @@ The package is created with an idea to support any communication bus:
  - `K-Line <https://en.wikipedia.org/wiki/K-Line>`_
 """
 
-__all__ = ["messages"]
-__version__ = "0.1.0"
+__all__ = ["messages", "segmentation", "transport_interface"]
+
+__version__ = "0.1.1"
 __author__ = "Maciej Dąbrowski"
+__maintainer__ = "Maciej Dąbrowski"
+__credits__ = ["Maciej Dąbrowski (https://www.linkedin.com/in/maciej-dabrowski-test-engineer/)",
+               "Merit Automotive (https://merit-automotive.com/)"]
 __email__ = "uds-package-development@googlegroups.com"
+__license__ = "MIT"
