@@ -1,7 +1,7 @@
 """
 Module with common implementation of UDS packets for all bus types.
 
-UDS Packets are defined on middle layers of UDS OSI Model.
+:ref:`UDS Packets <knowledge-base-uds-packet>` are defined on middle layers of UDS OSI Model.
 """
 
 __all__ = ["AbstractUdsPacketType", "AbstractUdsPacket", "AbstractUdsPacketRecord",
@@ -24,12 +24,24 @@ class AbstractUdsPacketType(NibbleEnum, ValidatedEnum, ExtendableEnum):
     """
     Abstract definition of UDS packet type.
 
-    Packet type information is carried by Network Protocol Control Information (N_PCI).
+    Packet type information is carried by :ref:`Network Protocol Control Information (N_PCI) <knowledge-base-n-pci>`.
     Enums with packet types (N_PCI) values for certain buses (e.g. CAN, LIN, FlexRay) must inherit after this class.
 
     Note: There are some differences in values for each bus (e.g. LIN does not use Flow Control).
     """
 
+    @classmethod
+    @abstractmethod
+    def is_initial_packet_type(cls, value: Any) -> bool:  # type: ignore
+        """
+        Check whether given argument is a member or a value of packet type that initiates a diagnostic message.
+
+        :param value: Value to check.
+
+        :return: True if given argument is a packet type that initiates a diagnostic message, else False.
+        """
+        cls.validate_member(value)
+
 
 class AbstractUdsPacket(ABC):
     """Abstract definition of UDS Packet (Network Protocol Data Unit - N_PDU)."""
